# sparkfly
The Sparkfly Platform provides a full lifecycle for promotions and rewards from creation to distribution to settlement. The platform integrates in real-time at the point-of-sale and provides item level discounting and tracking. The capabilities of the Sparkfly Platform are available through the use of the Sparkfly Platform API.

The Sparkfly documentation site is under development. If the documentation you're after isn't available here, please contact support@sparkfly.com and we will get you what you need.

This Python package is automatically generated by the [OpenAPI Generator](https://openapi-generator.tech) project:

- API version: 1.0
- Package version: 1.3.5
- Generator version: 7.14.0
- Build package: org.openapitools.codegen.languages.PythonClientCodegen
For more information, please visit [https://help.sparkfly.com/](https://help.sparkfly.com/)

## Requirements.

Python 3.9+

## Installation & Usage
### pip install

If the python package is hosted on a repository, you can install directly using:

```sh
pip install git+https://github.com/GIT_USER_ID/GIT_REPO_ID.git
```
(you may need to run `pip` with root permission: `sudo pip install git+https://github.com/GIT_USER_ID/GIT_REPO_ID.git`)

Then import the package:
```python
import sparkfly
```

### Setuptools

Install via [Setuptools](http://pypi.python.org/pypi/setuptools).

```sh
python setup.py install --user
```
(or `sudo python setup.py install` to install the package for all users)

Then import the package:
```python
import sparkfly
```

### Tests

Execute `pytest` to run the tests.

## Getting Started

Please follow the [installation procedure](#installation--usage) and then run the following:

```python

import sparkfly
from sparkfly.rest import ApiException
from pprint import pprint

# Defining the host is optional and defaults to https://api-staging.sparkfly.com/v1.0
# See configuration.py for a list of all supported configuration parameters.
configuration = sparkfly.Configuration(
    host = "https://api-staging.sparkfly.com/v1.0"
)

# The client must configure the authentication and authorization parameters
# in accordance with the API server security policy.
# Examples for each auth method are provided below, use the example that
# satisfies your auth use case.

# Configure API key authorization: XAuthToken
configuration.api_key['XAuthToken'] = os.environ["API_KEY"]

# Uncomment below to setup prefix (e.g. Bearer) for API key, if needed
# configuration.api_key_prefix['XAuthToken'] = 'Bearer'


# Enter a context with an instance of the API client
async with sparkfly.ApiClient(configuration) as api_client:
    # Create an instance of the API class
    api_instance = sparkfly.AudiencesApi(api_client)
    content_type = 'content_type_example' # str | application/json (optional)
    create_audience_request = sparkfly.CreateAudienceRequest() # CreateAudienceRequest |  (optional)

    try:
        # Create an Audience
        api_response = await api_instance.create_audience(content_type=content_type, create_audience_request=create_audience_request)
        print("The response of AudiencesApi->create_audience:\n")
        pprint(api_response)
    except ApiException as e:
        print("Exception when calling AudiencesApi->create_audience: %s\n" % e)

```

## Documentation for API Endpoints

All URIs are relative to *https://api-staging.sparkfly.com/v1.0*

Class | Method | HTTP request | Description
------------ | ------------- | ------------- | -------------
*AudiencesApi* | [**create_audience**](docs/AudiencesApi.md#create_audience) | **POST** /audiences | Create an Audience
*AudiencesApi* | [**create_sub_audience**](docs/AudiencesApi.md#create_sub_audience) | **POST** /audiences/{audience_id}/sub_audiences | Create a Sub-Audience
*AudiencesApi* | [**delete_audience**](docs/AudiencesApi.md#delete_audience) | **DELETE** /audiences/{audience_id} | Remove an Audience
*AudiencesApi* | [**delete_sub_audience**](docs/AudiencesApi.md#delete_sub_audience) | **DELETE** /audiences/{audience_id}/sub_audiences/{sub_audience_id} | Remove a Sub-Audience
*AudiencesApi* | [**get_audience**](docs/AudiencesApi.md#get_audience) | **GET** /audiences/{audience_id} | Retrieve an Audience
*AudiencesApi* | [**get_sub_audience**](docs/AudiencesApi.md#get_sub_audience) | **GET** /audiences/{audience_id}/sub_audiences/{sub_audience_id} | Retrieve a Sub-Audience
*AudiencesApi* | [**list_audiences**](docs/AudiencesApi.md#list_audiences) | **GET** /audiences | List all Audiences
*AudiencesApi* | [**list_sub_audiences**](docs/AudiencesApi.md#list_sub_audiences) | **GET** /audiences/{audience_id}/sub_audiences | List all Sub-Audiences
*AudiencesApi* | [**update_audience**](docs/AudiencesApi.md#update_audience) | **PUT** /audiences/{audience_id} | Update an Audience
*AudiencesApi* | [**update_sub_audience**](docs/AudiencesApi.md#update_sub_audience) | **PUT** /audiences/{audience_id}/sub_audiences/{sub_audience_id} | Update a Sub-Audience
*AuthenticationApi* | [**authenticate**](docs/AuthenticationApi.md#authenticate) | **POST** /auth | Request an Authentication Token
*BIStoreListsApi* | [**list_bi_store_lists**](docs/BIStoreListsApi.md#list_bi_store_lists) | **GET** /merchants/bi_store_lists | List all BI Store Lists
*CampaignsApi* | [**approve_campaign**](docs/CampaignsApi.md#approve_campaign) | **PUT** /campaigns/{campaign_id}/actions/{action} | Set a Campaign&#39;s Status
*CampaignsApi* | [**create_campaign**](docs/CampaignsApi.md#create_campaign) | **POST** /campaigns | Create a Campaign
*CampaignsApi* | [**get_campaign**](docs/CampaignsApi.md#get_campaign) | **GET** /campaigns/{campaign_id} | Retrieve a Campaign by Campaign ID
*CampaignsApi* | [**list_campaign_tags**](docs/CampaignsApi.md#list_campaign_tags) | **GET** /campaigns/tags | Retrieve Campaign Tags
*CampaignsApi* | [**list_campaigns**](docs/CampaignsApi.md#list_campaigns) | **GET** /campaigns | List all Campaigns
*CampaignsApi* | [**update_campaign**](docs/CampaignsApi.md#update_campaign) | **PUT** /campaigns/{campaign_id} | Update a Campaign by Campaign ID
*CredentialsApi* | [**create_credential**](docs/CredentialsApi.md#create_credential) | **POST** /credentials | Create a Credential
*CtmApi* | [**ctm_allocate**](docs/CtmApi.md#ctm_allocate) | **POST** /ctm/allocate/{site_id}/{credential} | CTM Allocate
*CtmApi* | [**ctm_create_member**](docs/CtmApi.md#ctm_create_member) | **POST** /v2/ctm/members/{site_id}/{credential} | CTM Update Response
*CtmApi* | [**ctm_create_member_by_site**](docs/CtmApi.md#ctm_create_member_by_site) | **POST** /v2/ctm/members/{site_id} | CTM Update Response
*CtmApi* | [**ctm_deallocate**](docs/CtmApi.md#ctm_deallocate) | **POST** /ctm/deallocate/{site_id} | CTM Dealocate
*CtmApi* | [**ctm_get_custom_messages**](docs/CtmApi.md#ctm_get_custom_messages) | **GET** /v2/ctm/customposmessages | CTM Custom Messages
*CtmApi* | [**ctm_get_member**](docs/CtmApi.md#ctm_get_member) | **GET** /ctm/members/{site_id}/{credential} | CTM Show Response
*CtmApi* | [**ctm_get_qitems**](docs/CtmApi.md#ctm_get_qitems) | **POST** /ctm/qitems/{site_id}/{credential} | CTM Qitems
*CtmApi* | [**ctm_get_store**](docs/CtmApi.md#ctm_get_store) | **GET** /v2/ctm/stores | CTM Stores
*CtmApi* | [**ctm_update_member**](docs/CtmApi.md#ctm_update_member) | **PUT** /ctm/members/{site_id}/{credential} | CTM Update Response
*CtmApi* | [**ctm_update_member_v2**](docs/CtmApi.md#ctm_update_member_v2) | **PUT** /v2/ctm/members/{site_id}/{credential} | CTM Show Response
*CtmApi* | [**ctm_update_transaction**](docs/CtmApi.md#ctm_update_transaction) | **PUT** /ctm/members/{site_id} | CTM Transaction Update
*EligibleItemSetsApi* | [**create_eligible_item_set**](docs/EligibleItemSetsApi.md#create_eligible_item_set) | **POST** /offers/{offer_id}/eligible_item_sets | Create an Eligible Item Set
*EligibleItemSetsApi* | [**delete_eligible_item_set**](docs/EligibleItemSetsApi.md#delete_eligible_item_set) | **DELETE** /offers/{offer_id}/eligible_item_sets/{id} | Remove an Eligible Item Set
*EligibleItemSetsApi* | [**get_eligible_item_set**](docs/EligibleItemSetsApi.md#get_eligible_item_set) | **GET** /offers/{offer_id}/eligible_item_sets/{id} | Get an Eligible Item Set
*EligibleItemSetsApi* | [**list_eligible_item_sets**](docs/EligibleItemSetsApi.md#list_eligible_item_sets) | **GET** /offers/{offer_id}/eligible_item_sets | List all Eligible Item Sets
*EligibleItemSetsApi* | [**update_eligible_item_set**](docs/EligibleItemSetsApi.md#update_eligible_item_set) | **PUT** /offers/{offer_id}/eligible_item_sets/{id} | Update an Eligible Item Set
*EmailOptInApi* | [**create_optin**](docs/EmailOptInApi.md#create_optin) | **POST** /optins | Email Opt In
*EventNotificationsApi* | [**create_callback**](docs/EventNotificationsApi.md#create_callback) | **POST** /event_notifications/callbacks | Create Callback
*EventNotificationsApi* | [**create_subscription**](docs/EventNotificationsApi.md#create_subscription) | **POST** /event_notifications/subscriptions | Create Subscription
*EventNotificationsApi* | [**delete_callback**](docs/EventNotificationsApi.md#delete_callback) | **DELETE** /event_notifications/callbacks/{callback_id} | Delete Callback
*EventNotificationsApi* | [**delete_subscription**](docs/EventNotificationsApi.md#delete_subscription) | **DELETE** /event_notifications/subscriptions/{subscription_id} | Delete Subscription
*EventNotificationsApi* | [**get_callback**](docs/EventNotificationsApi.md#get_callback) | **GET** /event_notifications/callbacks/{callback_id} | Get Callback by ID
*EventNotificationsApi* | [**get_subscription**](docs/EventNotificationsApi.md#get_subscription) | **GET** /event_notifications/subscriptions/{subscription_id} | Get Subscription by ID
*EventNotificationsApi* | [**list_callbacks**](docs/EventNotificationsApi.md#list_callbacks) | **GET** /event_notifications/callbacks | List Callbacks
*EventNotificationsApi* | [**list_subscriptions**](docs/EventNotificationsApi.md#list_subscriptions) | **GET** /event_notifications/subscriptions | List Subscriptions
*ImpressionsApi* | [**create_impression**](docs/ImpressionsApi.md#create_impression) | **POST** /impressions | Create an Impression
*ImpressionsApi* | [**delete_impression**](docs/ImpressionsApi.md#delete_impression) | **DELETE** /impressions/{id} | Delete an Impression
*ImpressionsApi* | [**list_impressions**](docs/ImpressionsApi.md#list_impressions) | **GET** /impressions | List Impressions
*ItemsApi* | [**add_item_to_set**](docs/ItemsApi.md#add_item_to_set) | **POST** /item_sets/{item_set_id}/items/{id} | Add Item to Set
*ItemsApi* | [**create_item**](docs/ItemsApi.md#create_item) | **POST** /items | Create Item
*ItemsApi* | [**create_item_set**](docs/ItemsApi.md#create_item_set) | **POST** /item_sets | Item Set Create
*ItemsApi* | [**delete_item**](docs/ItemsApi.md#delete_item) | **DELETE** /items/{id} | Delete Item
*ItemsApi* | [**delete_item_set**](docs/ItemsApi.md#delete_item_set) | **DELETE** /item_sets/{item_set_id} | Delete an Item Set
*ItemsApi* | [**get_item**](docs/ItemsApi.md#get_item) | **GET** /items/{id} | Get Item
*ItemsApi* | [**get_item_set**](docs/ItemsApi.md#get_item_set) | **GET** /item_sets/{item_set_id} | Get an Item Set
*ItemsApi* | [**list_item_sets**](docs/ItemsApi.md#list_item_sets) | **GET** /item_sets | Item Set Index
*ItemsApi* | [**list_items**](docs/ItemsApi.md#list_items) | **GET** /items | Item Index
*ItemsApi* | [**list_set_items**](docs/ItemsApi.md#list_set_items) | **GET** /item_sets/{item_set_id}/items | Item Set Item Index
*ItemsApi* | [**remove_item_from_set**](docs/ItemsApi.md#remove_item_from_set) | **DELETE** /item_sets/{item_set_id}/items/{id} | Remove Item from Set
*ItemsApi* | [**update_item**](docs/ItemsApi.md#update_item) | **PUT** /items/{id} | Update Item
*ItemsApi* | [**update_item_set**](docs/ItemsApi.md#update_item_set) | **PUT** /item_sets/{item_set_id} | Update an Item Set
*MemberPrivacyApi* | [**export_member_privacy**](docs/MemberPrivacyApi.md#export_member_privacy) | **GET** /privacy/member/export | Exports Data Associated with a Member
*MemberPrivacyApi* | [**request_member_deletion**](docs/MemberPrivacyApi.md#request_member_deletion) | **POST** /privacy/member/delete_request | Creates a Deletion Request for a Member
*MembersApi* | [**create_member**](docs/MembersApi.md#create_member) | **POST** /members | Create a Member
*MembersApi* | [**create_profile**](docs/MembersApi.md#create_profile) | **POST** /members/{id}/profile | Create/Update a Member Profile
*MembersApi* | [**delete_member**](docs/MembersApi.md#delete_member) | **DELETE** /members/{member_id} | Remove a Member
*MembersApi* | [**get_member**](docs/MembersApi.md#get_member) | **GET** /members/{member_id} | Find a Member
*MembersApi* | [**get_profile**](docs/MembersApi.md#get_profile) | **GET** /members/{id}/profile | Retrieve a Member Profile
*MembersApi* | [**list_members**](docs/MembersApi.md#list_members) | **GET** /members | List Members
*MembersApi* | [**register_member**](docs/MembersApi.md#register_member) | **POST** /members/register | Register a New Member
*MembersApi* | [**search_members**](docs/MembersApi.md#search_members) | **GET** /members/search | Search for a Member
*MembersApi* | [**update_member**](docs/MembersApi.md#update_member) | **PUT** /members/{member_id} | Update a Member
*OfferListsApi* | [**create_offer_list**](docs/OfferListsApi.md#create_offer_list) | **POST** /offer_lists | Create an Offer List
*OfferListsApi* | [**delete_offer_list**](docs/OfferListsApi.md#delete_offer_list) | **DELETE** /offer_lists/{offer_list_id} | Remove an Offer List
*OfferListsApi* | [**get_offer_list**](docs/OfferListsApi.md#get_offer_list) | **GET** /offer_lists/{offer_list_id} | Retrieve an Offer List
*OfferListsApi* | [**list_offer_lists**](docs/OfferListsApi.md#list_offer_lists) | **GET** /offer_lists | List all Offer Lists
*OfferListsApi* | [**update_offer_list**](docs/OfferListsApi.md#update_offer_list) | **PUT** /offer_lists/{offer_list_id} | Update an Offer List
*OfferPOSOfferCodesApi* | [**create_pos_code**](docs/OfferPOSOfferCodesApi.md#create_pos_code) | **POST** /offers/{offer_id}/pos_offer_codes | Create an Offer POS Offer Code
*OfferPOSOfferCodesApi* | [**delete_pos_code**](docs/OfferPOSOfferCodesApi.md#delete_pos_code) | **DELETE** /offers/{offer_id}/pos_offer_codes/{id} | Remove an Offer POS Offer Code
*OfferPOSOfferCodesApi* | [**get_offer_pos_code**](docs/OfferPOSOfferCodesApi.md#get_offer_pos_code) | **GET** /offers/{offer_id}/pos_offer_codes/{id} | Get an Offer POS Offer Code
*OfferPOSOfferCodesApi* | [**list_pos_codes**](docs/OfferPOSOfferCodesApi.md#list_pos_codes) | **GET** /offers/{offer_id}/pos_offer_codes | List all Offer POS Offer Codes
*OfferPOSOfferCodesApi* | [**update_pos_code**](docs/OfferPOSOfferCodesApi.md#update_pos_code) | **PUT** /offers/{offer_id}/pos_offer_codes/{id} | Update an Offer POS Offer Code
*OfferStatesApi* | [**create_offer_state**](docs/OfferStatesApi.md#create_offer_state) | **POST** /members/offer_states | Create Offer State from Query Parameters
*OfferStatesApi* | [**get_offer_state**](docs/OfferStatesApi.md#get_offer_state) | **GET** /members/{member_id}/offer_states/{offerstate_id} | Get Offer State by Offer State ID
*OfferStatesApi* | [**issue_offer**](docs/OfferStatesApi.md#issue_offer) | **POST** /members/offer_states/issue | Issue an Offer to a member (high throughput)
*OfferStatesApi* | [**issue_offer_state**](docs/OfferStatesApi.md#issue_offer_state) | **POST** /members/{member_id}/offer_states | Create Offer State
*OfferStatesApi* | [**list_members_offers**](docs/OfferStatesApi.md#list_members_offers) | **GET** /members/{member_id}/offers/{offer_id} | Get Offer State by Offer ID
*OfferStatesApi* | [**list_offer_states**](docs/OfferStatesApi.md#list_offer_states) | **GET** /members/{member_id}/offer_states | Get all Offer States
*OfferStatesApi* | [**query_offer_states**](docs/OfferStatesApi.md#query_offer_states) | **GET** /members/offer_states | Get Offer State from Query Parameters
*OfferStatesApi* | [**redeem_offer_state**](docs/OfferStatesApi.md#redeem_offer_state) | **POST** /members/{member_id}/offer_states/{offerstate_id} | Update Offer State - Post
*OfferStatesApi* | [**update_offer_state**](docs/OfferStatesApi.md#update_offer_state) | **PUT** /members/{member_id}/offer_states/{offerstate_id} | Update Offer State
*OfferStatesApi* | [**void_offer_state**](docs/OfferStatesApi.md#void_offer_state) | **POST** /members/{member_id}/offer_states/{offerstate_id}/void | Void Offer State
*OfferStatesApi* | [**void_offer_state_by_identifier**](docs/OfferStatesApi.md#void_offer_state_by_identifier) | **POST** /members/offer_states/{offerstate_id}/void | Void Offer State by Member Identifier
*OffersApi* | [**create_offer**](docs/OffersApi.md#create_offer) | **POST** /offers | Create an Offer
*OffersApi* | [**delete_offer**](docs/OffersApi.md#delete_offer) | **DELETE** /offers/{offer_id} | Delete an Offer
*OffersApi* | [**get_offer**](docs/OffersApi.md#get_offer) | **GET** /offers/{offer_id} | Find an Offer
*OffersApi* | [**list_offers**](docs/OffersApi.md#list_offers) | **GET** /offers | List all Offers
*OffersApi* | [**update_offer**](docs/OffersApi.md#update_offer) | **PUT** /offers/{offer_id} | Update an Offer
*POSOfferCodesApi* | [**get_pos_code**](docs/POSOfferCodesApi.md#get_pos_code) | **GET** /pos_offer_codes/{id} | Get a POS Offer Code
*POSOfferCodesApi* | [**list_all_pos_codes**](docs/POSOfferCodesApi.md#list_all_pos_codes) | **GET** /pos_offer_codes | List all POS Offer Codes
*StoreListsApi* | [**create_store_list**](docs/StoreListsApi.md#create_store_list) | **POST** /merchants/{merchant_id}/store_lists | Create a Store List
*StoreListsApi* | [**delete_store_list**](docs/StoreListsApi.md#delete_store_list) | **DELETE** /merchants/{merchant_id}/store_lists/{store_list_id} | Remove a Store List
*StoreListsApi* | [**get_store_list**](docs/StoreListsApi.md#get_store_list) | **GET** /merchants/{merchant_id}/store_lists/{store_list_id} | Retrieve a Store List
*StoreListsApi* | [**list_store_lists**](docs/StoreListsApi.md#list_store_lists) | **GET** /merchants/{merchant_id}/store_lists | List all Store Lists
*StoreListsApi* | [**update_store_list**](docs/StoreListsApi.md#update_store_list) | **PUT** /merchants/{merchant_id}/store_lists/{store_list_id} | Update a Store List
*StoresApi* | [**create_store**](docs/StoresApi.md#create_store) | **POST** /merchants/{merchant_id}/stores | Create a Store
*StoresApi* | [**delete_store**](docs/StoresApi.md#delete_store) | **DELETE** /merchants/{merchant_id}/stores/{store_id} | Remove a Store
*StoresApi* | [**get_store**](docs/StoresApi.md#get_store) | **GET** /merchants/{merchant_id}/stores/{store_id} | Retrieve a Store
*StoresApi* | [**list_stores**](docs/StoresApi.md#list_stores) | **GET** /merchants/{merchant_id}/stores | List all Stores
*StoresApi* | [**list_stores_index**](docs/StoresApi.md#list_stores_index) | **GET** /merchants/stores/index | List all Stores with Active Offers
*StoresApi* | [**update_store**](docs/StoresApi.md#update_store) | **PUT** /merchants/{merchant_id}/stores/{store_id} | Update a Store
*TemplatesApi* | [**list_templates**](docs/TemplatesApi.md#list_templates) | **GET** /templates | Get all Templates
*TransactionsApi* | [**get_transaction**](docs/TransactionsApi.md#get_transaction) | **GET** /transactions/{transaction_id} | Get Transaction Details


## Documentation For Models

 - [ApiError](docs/ApiError.md)
 - [AtomicMemberCreateBody](docs/AtomicMemberCreateBody.md)
 - [AtomicMemberCreateBodyMember](docs/AtomicMemberCreateBodyMember.md)
 - [AtomicMemberCreateBodyMemberCredentialsInner](docs/AtomicMemberCreateBodyMemberCredentialsInner.md)
 - [AtomicMemberCreateBodyMemberCredentialsInnerCredential](docs/AtomicMemberCreateBodyMemberCredentialsInnerCredential.md)
 - [AtomicMemberCreateBodyMemberLoyaltyEnrollmentsInner](docs/AtomicMemberCreateBodyMemberLoyaltyEnrollmentsInner.md)
 - [AtomicMemberCreateBodyMemberLoyaltyEnrollmentsInnerLoyaltyEnrollment](docs/AtomicMemberCreateBodyMemberLoyaltyEnrollmentsInnerLoyaltyEnrollment.md)
 - [AtomicMemberCreateBodyMemberMemberProfile](docs/AtomicMemberCreateBodyMemberMemberProfile.md)
 - [AtomicMemberResponseBody](docs/AtomicMemberResponseBody.md)
 - [AtomicMemberResponseBodyMember](docs/AtomicMemberResponseBodyMember.md)
 - [AtomicMemberResponseBodyMemberCredentialsInner](docs/AtomicMemberResponseBodyMemberCredentialsInner.md)
 - [AtomicMemberResponseBodyMemberCredentialsInnerCredential](docs/AtomicMemberResponseBodyMemberCredentialsInnerCredential.md)
 - [AtomicMemberResponseBodyMemberLoyaltyEnrollmentsInner](docs/AtomicMemberResponseBodyMemberLoyaltyEnrollmentsInner.md)
 - [AtomicMemberResponseBodyMemberLoyaltyEnrollmentsInnerLoyaltyEnrollment](docs/AtomicMemberResponseBodyMemberLoyaltyEnrollmentsInnerLoyaltyEnrollment.md)
 - [AtomicMemberResponseBodyMemberMemberProfile](docs/AtomicMemberResponseBodyMemberMemberProfile.md)
 - [Audience](docs/Audience.md)
 - [AudienceData](docs/AudienceData.md)
 - [AudienceIndexBody](docs/AudienceIndexBody.md)
 - [AudienceIndexData](docs/AudienceIndexData.md)
 - [Authenticate401Response](docs/Authenticate401Response.md)
 - [BiStoreList](docs/BiStoreList.md)
 - [BiStoreListStoreListsInner](docs/BiStoreListStoreListsInner.md)
 - [Callback](docs/Callback.md)
 - [CallbackRequest](docs/CallbackRequest.md)
 - [CallbackRequestCallback](docs/CallbackRequestCallback.md)
 - [CallbackResponse](docs/CallbackResponse.md)
 - [CallbacksIndexBody](docs/CallbacksIndexBody.md)
 - [CampaignIndexBody](docs/CampaignIndexBody.md)
 - [CampaignRequest](docs/CampaignRequest.md)
 - [CampaignRequestCampaign](docs/CampaignRequestCampaign.md)
 - [CampaignResponse](docs/CampaignResponse.md)
 - [CampaignResponseCampaign](docs/CampaignResponseCampaign.md)
 - [CampaignTagsResponse](docs/CampaignTagsResponse.md)
 - [ClarkAndRiggsIndexBody](docs/ClarkAndRiggsIndexBody.md)
 - [ClarkAndRiggsProductCreateBody](docs/ClarkAndRiggsProductCreateBody.md)
 - [ClarkAndRiggsProductResponseBody](docs/ClarkAndRiggsProductResponseBody.md)
 - [ClarkAndRiggsProductResponseBodyClarkAndRiggsProduct](docs/ClarkAndRiggsProductResponseBodyClarkAndRiggsProduct.md)
 - [CreateAudienceRequest](docs/CreateAudienceRequest.md)
 - [CreateOfferListRequest](docs/CreateOfferListRequest.md)
 - [CreateOfferListRequestOfferList](docs/CreateOfferListRequestOfferList.md)
 - [CreateProfileRequest](docs/CreateProfileRequest.md)
 - [CreateSubAudienceRequest](docs/CreateSubAudienceRequest.md)
 - [CredentialBatchIndexBody](docs/CredentialBatchIndexBody.md)
 - [CredentialBatchRequest](docs/CredentialBatchRequest.md)
 - [CredentialBatchResponseBody](docs/CredentialBatchResponseBody.md)
 - [CredentialBatchResponseBodyCredentialBatch](docs/CredentialBatchResponseBodyCredentialBatch.md)
 - [CredentialBatchResponseBodyCredentialBatchCampaign](docs/CredentialBatchResponseBodyCredentialBatchCampaign.md)
 - [CredentialBatchResponseBodyCredentialBatchOffer](docs/CredentialBatchResponseBodyCredentialBatchOffer.md)
 - [CredentialCreateRequest](docs/CredentialCreateRequest.md)
 - [CredentialCreateRequestCredential](docs/CredentialCreateRequestCredential.md)
 - [CredentialCreateResponse](docs/CredentialCreateResponse.md)
 - [CredentialCreateResponseCredential](docs/CredentialCreateResponseCredential.md)
 - [CtmQitemsRequest](docs/CtmQitemsRequest.md)
 - [CtmRedemptionJobRequest](docs/CtmRedemptionJobRequest.md)
 - [CtmRedemptionJobRequestItemsInner](docs/CtmRedemptionJobRequestItemsInner.md)
 - [CtmRedemptionJobRequestRedeemedOffersInner](docs/CtmRedemptionJobRequestRedeemedOffersInner.md)
 - [CtmRedemptionJobRequestRedeemedOffersInnerQualifyingItemsInner](docs/CtmRedemptionJobRequestRedeemedOffersInnerQualifyingItemsInner.md)
 - [CtmRedemptionJobRequestSelectedOffersInner](docs/CtmRedemptionJobRequestSelectedOffersInner.md)
 - [CtmTransactionJobRequest](docs/CtmTransactionJobRequest.md)
 - [CtmTransactionShowResponse](docs/CtmTransactionShowResponse.md)
 - [CtmTransactionShowResponseAvailibleOffersInner](docs/CtmTransactionShowResponseAvailibleOffersInner.md)
 - [CtmTransactionShowResponseReusableOffers](docs/CtmTransactionShowResponseReusableOffers.md)
 - [CtmTransactionShowResponseTransaction](docs/CtmTransactionShowResponseTransaction.md)
 - [CtmTransactionShowResponseTransactionAddOffersInner](docs/CtmTransactionShowResponseTransactionAddOffersInner.md)
 - [CtmTransactionShowResponseTransactionAddOffersInnerQualifyingItemsInner](docs/CtmTransactionShowResponseTransactionAddOffersInnerQualifyingItemsInner.md)
 - [CtmTransactionShowResponseTransactionAvailibleOffersInner](docs/CtmTransactionShowResponseTransactionAvailibleOffersInner.md)
 - [CtmTransactionShowResponseTransactionCredentialsInner](docs/CtmTransactionShowResponseTransactionCredentialsInner.md)
 - [CtmTransactionShowResponseTransactionCredentialsInnerTxCredential](docs/CtmTransactionShowResponseTransactionCredentialsInnerTxCredential.md)
 - [CtmTransactionShowResponseTransactionDisplayMessagesInner](docs/CtmTransactionShowResponseTransactionDisplayMessagesInner.md)
 - [CtmTransactionShowResponseTransactionErrorsInner](docs/CtmTransactionShowResponseTransactionErrorsInner.md)
 - [CtmTransactionShowResponseTransactionRecieptMessagesInner](docs/CtmTransactionShowResponseTransactionRecieptMessagesInner.md)
 - [EmailOptIn](docs/EmailOptIn.md)
 - [EmailOptInError](docs/EmailOptInError.md)
 - [Errors](docs/Errors.md)
 - [HealthCheck](docs/HealthCheck.md)
 - [Impression](docs/Impression.md)
 - [ImpressionAllOfImpression](docs/ImpressionAllOfImpression.md)
 - [ImpressionErrorBody](docs/ImpressionErrorBody.md)
 - [ImpressionIndexBody](docs/ImpressionIndexBody.md)
 - [ImpressionRequest](docs/ImpressionRequest.md)
 - [ImpressionRequestImpression](docs/ImpressionRequestImpression.md)
 - [ImpressionRequestImpressionAnnotations](docs/ImpressionRequestImpressionAnnotations.md)
 - [IssueOffer201Response](docs/IssueOffer201Response.md)
 - [IssueOffer201ResponseOfferState](docs/IssueOffer201ResponseOfferState.md)
 - [IssueOfferRequest](docs/IssueOfferRequest.md)
 - [IssueOfferRequestOfferState](docs/IssueOfferRequestOfferState.md)
 - [Item](docs/Item.md)
 - [ItemAllOfItem](docs/ItemAllOfItem.md)
 - [ItemIndexBody](docs/ItemIndexBody.md)
 - [ItemRequest](docs/ItemRequest.md)
 - [ItemRequestItem](docs/ItemRequestItem.md)
 - [ItemSet](docs/ItemSet.md)
 - [ItemSetAllOfItemSet](docs/ItemSetAllOfItemSet.md)
 - [ItemSetIndexBody](docs/ItemSetIndexBody.md)
 - [ItemSetRequest](docs/ItemSetRequest.md)
 - [ItemSetRequestItemSet](docs/ItemSetRequestItemSet.md)
 - [Member](docs/Member.md)
 - [MemberAllOfMember](docs/MemberAllOfMember.md)
 - [MemberIndexBody](docs/MemberIndexBody.md)
 - [MemberPrivacy](docs/MemberPrivacy.md)
 - [MemberPrivacyCredentialsInner](docs/MemberPrivacyCredentialsInner.md)
 - [MemberPrivacyMember](docs/MemberPrivacyMember.md)
 - [MemberProfile](docs/MemberProfile.md)
 - [MemberProfileData](docs/MemberProfileData.md)
 - [MemberRequest](docs/MemberRequest.md)
 - [MemberRequestMember](docs/MemberRequestMember.md)
 - [Offer](docs/Offer.md)
 - [OfferAllOfOffer](docs/OfferAllOfOffer.md)
 - [OfferEligibleItemSet](docs/OfferEligibleItemSet.md)
 - [OfferEligibleItemSetAllOfEligibleItemSet](docs/OfferEligibleItemSetAllOfEligibleItemSet.md)
 - [OfferEligibleItemSetRequest](docs/OfferEligibleItemSetRequest.md)
 - [OfferEligibleItemSetRequestEligibleItemSet](docs/OfferEligibleItemSetRequestEligibleItemSet.md)
 - [OfferEligibleItemsSetIndex](docs/OfferEligibleItemsSetIndex.md)
 - [OfferIndexBody](docs/OfferIndexBody.md)
 - [OfferList](docs/OfferList.md)
 - [OfferListData](docs/OfferListData.md)
 - [OfferListsIndexBody](docs/OfferListsIndexBody.md)
 - [OfferPosOfferCode](docs/OfferPosOfferCode.md)
 - [OfferPosOfferCodeAllOfOfferPosOfferCode](docs/OfferPosOfferCodeAllOfOfferPosOfferCode.md)
 - [OfferPosOfferCodeIndex](docs/OfferPosOfferCodeIndex.md)
 - [OfferPosOfferCodeRequest](docs/OfferPosOfferCodeRequest.md)
 - [OfferPosOfferCodeRequestOfferPosOfferCode](docs/OfferPosOfferCodeRequestOfferPosOfferCode.md)
 - [OfferRequest](docs/OfferRequest.md)
 - [OfferRequestOffer](docs/OfferRequestOffer.md)
 - [OfferRequestOfferEligibility](docs/OfferRequestOfferEligibility.md)
 - [OfferRequestOfferFormatting](docs/OfferRequestOfferFormatting.md)
 - [OfferRequestOfferFormattingEligibleStoreMap](docs/OfferRequestOfferFormattingEligibleStoreMap.md)
 - [OfferState](docs/OfferState.md)
 - [OfferStateAllOfOfferState](docs/OfferStateAllOfOfferState.md)
 - [OfferStateError](docs/OfferStateError.md)
 - [OfferStateIndexBody](docs/OfferStateIndexBody.md)
 - [OfferStateRequest](docs/OfferStateRequest.md)
 - [OfferStateRequestOfferState](docs/OfferStateRequestOfferState.md)
 - [OfferStateUpdate](docs/OfferStateUpdate.md)
 - [OfferStateUpdateOfferState](docs/OfferStateUpdateOfferState.md)
 - [PageResponseBody](docs/PageResponseBody.md)
 - [PosOfferCode](docs/PosOfferCode.md)
 - [PosOfferCodeAllOfPosOfferCode](docs/PosOfferCodeAllOfPosOfferCode.md)
 - [PosOfferCodeIndexBody](docs/PosOfferCodeIndexBody.md)
 - [Store](docs/Store.md)
 - [StoreAllOfStore](docs/StoreAllOfStore.md)
 - [StoreAllOfStoreLocation](docs/StoreAllOfStoreLocation.md)
 - [StoreIndexBody](docs/StoreIndexBody.md)
 - [StoreList](docs/StoreList.md)
 - [StoreListAllOfStoreList](docs/StoreListAllOfStoreList.md)
 - [StoreListIndexBody](docs/StoreListIndexBody.md)
 - [StoreListRequest](docs/StoreListRequest.md)
 - [StoreListRequestStoreList](docs/StoreListRequestStoreList.md)
 - [StoreRequest](docs/StoreRequest.md)
 - [StoreRequestStore](docs/StoreRequestStore.md)
 - [StoreRequestStoreContacts](docs/StoreRequestStoreContacts.md)
 - [StoreRequestStoreContactsPrimary](docs/StoreRequestStoreContactsPrimary.md)
 - [StoreRequestStoreLocation](docs/StoreRequestStoreLocation.md)
 - [SubAudience](docs/SubAudience.md)
 - [SubAudienceData](docs/SubAudienceData.md)
 - [SubAudienceIndexBody](docs/SubAudienceIndexBody.md)
 - [SubAudienceIndexData](docs/SubAudienceIndexData.md)
 - [Subscription](docs/Subscription.md)
 - [SubscriptionRequest](docs/SubscriptionRequest.md)
 - [SubscriptionRequestSubscription](docs/SubscriptionRequestSubscription.md)
 - [SubscriptionResponse](docs/SubscriptionResponse.md)
 - [SubscriptionsIndexBody](docs/SubscriptionsIndexBody.md)
 - [Template](docs/Template.md)
 - [Template2](docs/Template2.md)
 - [TemplateTemplatesInner](docs/TemplateTemplatesInner.md)
 - [TransactionAppliedCredential](docs/TransactionAppliedCredential.md)
 - [TransactionCampaign](docs/TransactionCampaign.md)
 - [TransactionCampaignOffer](docs/TransactionCampaignOffer.md)
 - [TransactionItem](docs/TransactionItem.md)
 - [TransactionRedemption](docs/TransactionRedemption.md)
 - [TransactionResponse](docs/TransactionResponse.md)
 - [TransactionResponseTransaction](docs/TransactionResponseTransaction.md)
 - [TransactionTotals](docs/TransactionTotals.md)


<a id="documentation-for-authorization"></a>
## Documentation For Authorization


Authentication schemes defined for the API:
<a id="XAuthToken"></a>
### XAuthToken

- **Type**: API key
- **API key parameter name**: X-Auth-Token
- **Location**: HTTP header

<a id="XAuthIdentity"></a>
### XAuthIdentity

- **Type**: API key
- **API key parameter name**: X-Auth-Identity
- **Location**: HTTP header

<a id="XAuthKey"></a>
### XAuthKey

- **Type**: API key
- **API key parameter name**: X-Auth-Key
- **Location**: HTTP header


## Author

support@sparkfly.com


